**Example 1: 获取组件市场组件信息**



Input: 

```
tccli iecp GetMarketComponent --cli-unfold-argument  \
    --ID 839900
```

Output: 
```
{
    "Response": {
        "RequestId": "5ebf13a2-f925-4ba7-adff-ddbc21d355e3",
        "AppName": "xxx",
        "ID": 70008,
        "Author": "xxx",
        "ReleaseTime": "xxx",
        "Outline": "xxx",
        "Detail": "xxx",
        "Icon": "xxx",
        "Version": "x.y.z",
        "WorkloadVisualConfig": "xxx"
    }
}
```

